:mod:`xoutil.data` - Useful data-structures and data related algorithms
========================================================================

.. automodule:: xoutil.data
   :members: adapt_exception

.. autoclass:: SmartDict(*args, **kwargs)

.. autoclass:: SortedSmartDict(*args, **kwargs)

.. autofunction:: smart_copy(source, target, full=False)
